@@ -31,17 +31,20 @@ class LogSniffer():
 
 
 	async def _retrieve_logs(self, system):
-		from os import mkdir
+		from pathlib import Path
 		import ftplib
 		
 		# connect ftp
-		ftp = ftplib.FTP(
-			system['master_ip'],
-			user=self.user_name,
-			passwd=self.password
-			)
-		ftp.timeout = 100
-		ftp.debugging = self.debug_ftp
+		try:
+			ftp = ftplib.FTP(
+				system['master_ip'],
+				user=self.user_name,
+				passwd=self.password
+				)
+			ftp.timeout = 100
+			ftp.debugging = self.debug_ftp
+		except TimeoutError as e:
+			error(f"amxlogs _retreive_logs() {system['full_name']}-{system['master_ip']} {e}")
 
 		# read top level directory
 		try:
@@ -55,31 +58,28 @@ class LogSniffer():
 				for file in files:
 					if (self.log == 'error_log' and file.lower().endswith('.log')) or file.endswith(f"{self.log}.txt") or file.endswith(f"{self.log.upper()}.TXT"):
 						await asyncio.sleep(0)
-						
+
+						Path(f"{self.output_dir}").mkdir(parents=True, exist_ok=True)
+
 						filename = f"{self.output_dir}{system['full_name']} {file}"
-						try:
-							mkdir(f"{self.output_dir}{[self.log]}")
-							debug(f"amxlogs.py created {self.output_dir}{[self.log]}")
-						except FileExistsError:
-							pass
 						with open(filename, 'wb+') as f:
 							ftp.retrbinary(f"RETR {file}", f.write)
-							debug(f"amxlogs.py retrieved {system['full_name']} {file}")
+							debug(f"amxlogs retrieved {system['full_name']} {file}")
 						
 						debug(ftp.retrlines('LIST'))
 
 						if self.clear_logs == 'True':
 							ftp.delete(file)
-							debug(f"amxlogs.py deleted {system['full_name']} {file}")
+							debug(f"amxlogs deleted {system['full_name']} {file}")
 				ftp.quit()
 				return
 			except Exception as e:
-				error(f"amxlogs.py _retrieve_logs() {self.log} for file in files: {e}")
+				error(f"amxlogs _retrieve_logs() {system['full_name']} {self.log} for file in files: {e}")
 				ftp.quit()
 				return
 
 		except Exception as e:
-			error(f"amxlogs.py _retrieve_logs() {system['full_name']} {self.log} {e}")
+			error(f"amxlogs _retrieve_logs() {system['full_name']} {self.log} {e}")
 			return
 
 
